@@ -1,7 +1,7 @@
 from gym.envs.registration import register
 from sumo_gym.envs.vrp import VRP, VRPEnv
 from sumo_gym.spaces.network import NetworkSpace
-from sumo_gym.utils.xml_utils import encode_xml, decode_xml
+from sumo_gym.utils.xml_utils import decode_xml
 from sumo_gym.utils.network_utils import calculate_dist, get_adj_list
 from sumo_gym.utils.svg_uitls import vehicle_marker
 from typing import Tuple
@@ -11,7 +11,6 @@ __all__ = (
     "VRP",
     "VRPEnv",
     "NetworkSpace",
-    "encode_xml",
     "decode_xml",
     "calculate_dist",
     "get_adj_list",
