@@ -1,10 +1,9 @@
 from typing import Tuple
-from sumo_gym.utils.xml_utils import encode_xml, decode_xml
+from sumo_gym.utils.xml_utils import decode_xml
 from sumo_gym.utils.network_utils import calculate_dist, get_adj_list
 from sumo_gym.utils.svg_uitls import vehicle_marker
 
 __all__ = (
-    "encode_xml",
     "decode_xml",
     "calculate_dist",
     "get_adj_list",
